==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/controllers/cms_public_contents_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe CmsPublicContentsController do
  fixtures :cms_pages, :cms_binds, :cms_bind_items, :cms_bind_contents, :cms_templates, :cms_page_titles, :cms_projects

  def login_as_admin
    login_as("admin")
  end

  describe "GET index" do
    it "should get index" do
      Dir.stub!(:glob).and_return([
          "/views/test",
          "/views/test/_show_fashion_bottom.html.erb",
          "/views/test/_show_fashion_bottom_en.html.erb",
          "/views/test/_show_fashion_bottom_ko.html.erb",
          "/views/test/_show_fashion_bottom_th.html.erb",
          "/views/test2/",
          "/views/test2/index.html.erb",
          "/views/test2/index_en.html.erb",
          "/views/test2/index_ko.html.erb",
          "/views/test2/index_th.html.erb",
          "/views/test2/test_en.html.erb",
          "/views/account/login.html.erb"
        ])
      login_as_admin
      get :index
      response.should be_success
      assigns("real_file_pathes").should_not be_nil

      @real_file_pathes = controller.instance_variable_get(:@real_file_pathes)
      @real_file_pathes.should include(
        '/views/test',
        '/views/test/_show_fashion_bottom.html.erb',
        '/views/test/_show_fashion_bottom_en.html.erb',
        '/views/test/_show_fashion_bottom_ko.html.erb',
        '/views/test/_show_fashion_bottom_th.html.erb',
        '/views/test2/',
        '/views/test2/index.html.erb',
        '/views/test2/index_en.html.erb',
        '/views/test2/index_ko.html.erb',
        '/views/test2/index_th.html.erb',
        '/views/account/login.html.erb'
      )
      controller.instance_variable_get(:@file_to_bind_in_opened_projects).should_not be_nil
      project = controller.instance_variable_get(:@file_to_bind_in_opened_projects)
      project["account/login.html.erb"].should_not be_nil

    end
  end


  describe "should stop" do
    before(:each) do
      tmp_dir = File.expand_path(File.join(Dir.tmpdir, "test_cms_public_contents"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'app', 'views'))
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
      CmsPublish.stub!(:send_reload_request)
    end

    it "should stop file" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root, "app", "views")
      FileUtils.copy_entry(fixture_file_path, uploaded_file_path)
      path = 'account/login_en.html.erb'
      File.exist?(uploaded_file_path).should be_true
      File.exist?(File.join(uploaded_file_path, path)).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :stop, {:path => "views/#{path}"}
      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should be_true
      File.exist?(File.expand_path("#{uploaded_file_path}/#{path}_bak")).should be_true
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb")).should be_true

    end
 
    it "should stop dir" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root,"app", "views")
      path = 'account'
      Dir.foreach(fixture_file_path) do | sub_path |
        unless sub_path == '.' || sub_path == '..'
          Dir.foreach(File.join(fixture_file_path,sub_path)) do | file |
            Dir.mkdir(File.join(uploaded_file_path,sub_path)) unless File.exist?(File.join(uploaded_file_path,sub_path))
            FileUtils.copy(File.join(fixture_file_path, sub_path, file), File.join(uploaded_file_path, sub_path, file)) if File.extname(file) == '.erb'
          end
        end
      end
      File.exist?(File.join(uploaded_file_path, path)).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :stop, {:path => "views/#{path}"}
      response.should redirect_to(:action => 'index')
      Dir.foreach(File.join(uploaded_file_path, path)) do | file_path |
        File.extname(file_path).should == '.erb_bak' unless file_path == '.' || file_path == '..'
      end
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb")).should be_true
    end

    it "should stop root dir" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root,"app", "views")

      Dir.foreach(fixture_file_path) do | sub_path |
        unless sub_path == '.' || sub_path == '..'
          Dir.foreach(File.join(fixture_file_path,sub_path)) do | file |
            Dir.mkdir(File.join(uploaded_file_path,sub_path)) unless File.exist?(File.join(uploaded_file_path,sub_path))
            FileUtils.copy(File.join(fixture_file_path, sub_path, file), File.join(uploaded_file_path, sub_path, file)) if File.extname(file) == '.erb'
          end
        end
      end
      File.exist?(uploaded_file_path).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :stop, {:path => "views"}
      response.should redirect_to(:action => 'index')
      Dir.foreach(uploaded_file_path) do | sub_path |
        unless sub_path == '.' || sub_path == '..'
          Dir.foreach(File.join(uploaded_file_path, sub_path)) do | file |
            File.extname(file).should == '.erb_bak'  unless file == '.' || file == '..'
          end
        end
      end
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb_bak")).should be_true
    end

    it "should public file" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root, "app", "views")
      FileUtils.copy_entry(fixture_file_path, uploaded_file_path)
      path = 'account/login_en.html.erb'
      File.rename(File.join(uploaded_file_path, path), File.join(uploaded_file_path, "#{path}_bak"))
      File.exist?(File.join(uploaded_file_path, "#{path}_bak")).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :public, {:path => "views/#{path}_bak"}
      response.should redirect_to(:action => 'index')
      File.exist?(File.join(uploaded_file_path, path)).should be_true
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb")).should be_true
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/controllers/cms_public_contents_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe CmsPublicContentsController do
  fixtures :cms_pages, :cms_binds, :cms_bind_items, :cms_bind_contents, :cms_templates, :cms_page_titles, :cms_projects, :cms_default_templates

  def login_as_admin
    login_as("admin")
  end

  describe "GET index" do
    it "should get index" do
      Dir.stub!(:glob).and_return([
          "/views/test",
          "/views/test/_show_fashion_bottom.html.erb",
          "/views/test/_show_fashion_bottom_en.html.erb",
          "/views/test/_show_fashion_bottom_ko.html.erb",
          "/views/test/_show_fashion_bottom_th.html.erb",
          "/views/test2/",
          "/views/test2/index.html.erb",
          "/views/test2/index_en.html.erb",
          "/views/test2/index_ko.html.erb",
          "/views/test2/index_th.html.erb",
          "/views/test2/test_en.html.erb",
          "/views/account/login.html.erb"
        ])
      login_as_admin
      get :index
      response.should be_success
      assigns("real_file_pathes").should_not be_nil

      @real_file_pathes = controller.instance_variable_get(:@real_file_pathes)
      @real_file_pathes.should include(
        '/views/test',
        '/views/test/_show_fashion_bottom.html.erb',
        '/views/test/_show_fashion_bottom_en.html.erb',
        '/views/test/_show_fashion_bottom_ko.html.erb',
        '/views/test/_show_fashion_bottom_th.html.erb',
        '/views/test2/',
        '/views/test2/index.html.erb',
        '/views/test2/index_en.html.erb',
        '/views/test2/index_ko.html.erb',
        '/views/test2/index_th.html.erb',
        '/views/account/login.html.erb'
      )
      controller.instance_variable_get(:@file_to_bind_in_opened_projects).should_not be_nil
      project = controller.instance_variable_get(:@file_to_bind_in_opened_projects)
      project["account/login.html.erb"].should_not be_nil

    end
  end


  describe "should stop" do
    before(:each) do
      tmp_dir = File.expand_path(File.join(RAILS_ROOT, "tmp", "test_cms_public_contents"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'app', 'views'))
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
      CmsPublish.stub!(:send_reload_request)
    end

    it "should stop file" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root, "app", "views")
      FileUtils.copy_entry(fixture_file_path, uploaded_file_path)
      path = 'account/login_en.html.erb'
      File.exist?(uploaded_file_path).should be_true
      File.exist?(File.join(uploaded_file_path, path)).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :stop, {:path => "views/#{path}"}
      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should be_true
      File.exist?(File.expand_path("#{uploaded_file_path}/#{path}_bak")).should be_true
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb")).should be_true

    end
 
    it "should stop dir" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root,"app", "views")
      path = 'account'
      Dir.foreach(fixture_file_path) do | sub_path |
        unless sub_path == '.' || sub_path == '..'
          Dir.foreach(File.join(fixture_file_path,sub_path)) do | file |
            Dir.mkdir(File.join(uploaded_file_path,sub_path)) unless File.exist?(File.join(uploaded_file_path,sub_path))
            FileUtils.copy(File.join(fixture_file_path, sub_path, file), File.join(uploaded_file_path, sub_path, file)) if File.extname(file) == '.erb'
          end
        end
      end
      File.exist?(File.join(uploaded_file_path, path)).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :stop, {:path => "views/#{path}"}
      response.should redirect_to(:action => 'index')
      Dir.foreach(File.join(uploaded_file_path, path)) do | file_path |
        File.extname(file_path).should == '.erb_bak' unless file_path == '.' || file_path == '..'
      end
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb")).should be_true
    end

    it "should stop root dir" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root,"app", "views")

      Dir.foreach(fixture_file_path) do | sub_path |
        unless sub_path == '.' || sub_path == '..'
          Dir.foreach(File.join(fixture_file_path,sub_path)) do | file |
            Dir.mkdir(File.join(uploaded_file_path,sub_path)) unless File.exist?(File.join(uploaded_file_path,sub_path))
            FileUtils.copy(File.join(fixture_file_path, sub_path, file), File.join(uploaded_file_path, sub_path, file)) if File.extname(file) == '.erb'
          end
        end
      end
      File.exist?(uploaded_file_path).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :stop, {:path => "views"}
      response.should redirect_to(:action => 'index')
      Dir.foreach(uploaded_file_path) do | sub_path |
        unless sub_path == '.' || sub_path == '..'
          Dir.foreach(File.join(uploaded_file_path, sub_path)) do | file |
            File.extname(file).should == '.erb_bak'  unless file == '.' || file == '..'
          end
        end
      end
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb_bak")).should be_true
    end

    it "should public file" do
      login_as_admin
      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_public_contents/data"
      uploaded_file_path = File.join(EcRider.config.ec_front_root, "app", "views")
      FileUtils.copy_entry(fixture_file_path, uploaded_file_path)
      path = 'account/login_en.html.erb'
      File.rename(File.join(uploaded_file_path, path), File.join(uploaded_file_path, "#{path}_bak"))
      File.exist?(File.join(uploaded_file_path, "#{path}_bak")).should be_true
      File.exist?("#{uploaded_file_path}/error_mailer/error_mail.erb").should be_true

      post :public, {:path => "views/#{path}_bak"}
      response.should redirect_to(:action => 'index')
      File.exist?(File.join(uploaded_file_path, path)).should be_true
      File.exist?(File.expand_path("#{uploaded_file_path}/error_mailer/error_mail.erb")).should be_true
    end
  end
end
